﻿using CustomListBoxDragDropBehavior_WPF;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Data;
using Telerik.Windows.Controls;
using Telerik.Windows.DragDrop;
using Telerik.Windows.DragDrop.Behaviors;

namespace CustomListBoxDragDropBehavior
{
    public class DragVisualProvider : DependencyObject, IDragVisualProvider
    {
        public DataTemplate DraggedItemTemplate
        {
            get
            {
                return (DataTemplate) GetValue(DraggedItemTemplateProperty);
            }
            set
            {
                SetValue(DraggedItemTemplateProperty, value);
            }
        }


        public static readonly DependencyProperty DraggedItemTemplateProperty =
        DependencyProperty.Register("DraggedItemTemplate", typeof(DataTemplate), typeof(DragVisualProvider), new PropertyMetadata(null));

        private FrameworkElement container;

        public FrameworkElement CreateDragVisual(DragVisualProviderState state)
        {
            var visual = new DragVisual();

            var theme = StyleManager.GetTheme(state.Host);
            if (theme != null)
            {
                StyleManager.SetTheme(visual, theme);
            }

            visual.Content = state.DraggedItems.OfType<object>().FirstOrDefault();
            this.container = state.DraggedItemContainers.FirstOrDefault() as FrameworkElement;
            this.container.Visibility = Visibility.Hidden;

            visual.ContentTemplate = DraggedItemTemplate;

            DragDropManager.AddDragDropCompletedHandler(state.Host, OnDragDropCompleted);

            return visual;
        }

        private void OnDragDropCompleted(object sender, DragDropCompletedEventArgs e)
        {
            this.container.Visibility = Visibility.Visible;
        }

        public Point GetDragVisualOffset(DragVisualProviderState state)
        {
            return state.RelativeStartPoint;
        }

        public bool UseDefaultCursors { get; set; }
    }
}
